@@ -7,7 +7,7 @@ from .models import UserDashboard, UserDashlet
 
 @login_required
 def generate_dashboard(request, app_name="", title=""):
-    """ Generate a dashboard view by looking up the dashboard from it's name
+    """ Generate a dashboard view by looking up the dashboard from its name
     responsive_dashboards is a list of all possible dashboards """
     dashboard_name = app_name
     if title:
@@ -71,7 +71,7 @@ def ajax_delete(request, app_name="", title=""):
 def add_dashlet(request, app_name="", title=""):
     """ Add a new user dashlet then reload the page """
     dashboard_name = '{0}__{1}'.format(app_name, title)
-    dashboard = responsive_dashboards[dashboard_name]
+    dashboard = dashboards.get_dashboard(dashboard_name)
     user_dashboard = UserDashboard.objects.get_or_create(
         dashboard_name=dashboard_name,
         user=request.user,
